==> Tagz-1.0.0.zip: Tagz/lang/ru.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Ключевые слова',
 'L_TITLE'=>'Изменить ключевые слова сайта',
 'L_DESCRIPTION'=>'Управление тегами сайта. Удалить или переименовать набор ключевых слов.',
#admin
 'L_CANCEL'=>'Отменить все',
 'L_DEVIENT'=>'становится',
 'L_POUR'=>'для',
 'L_SEARCH'=>'Искать в статьях с этим ключевым словом',
 'L_RESTORE'=>'восстановление',
 'L_DEL'=>'вычеркивать',
 'L_RESTORE_ALL'=>'Восстановить все поля, оставленные пустыми',
 'L_DEL_ALL'=>'Очистить все поля',
 'L_ART_NUM'=>'Для товара (ов) с номером (ами)',
 'L_HELP_TAG_FIELD'=>'Если поле пустое, ключевое слово удаляется после сохранения'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'обновление',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Файл Tags.xml обновляется по ключевым словам статей',
 'L_TAG_PLACEHOLDER'=>'Удалено, если оставить пустым',
 'L_DEDUPLICATED'=>'дедуплицированы',
 'L_IN_REALITY'=>'В реальности',
 'L_IS_UNIK'=>'Уникальный (это соло)',
 'L_DOUBLES'=>'двойной',
 'L_TRIPLES'=>'троек',
 'L_QUADRUPLES'=>'четверной',
 'L_QUINTUPLES'=>'пятикратный',
 'L_SEXTUPLES'=>'шестикратный',
 'L_SEPTUPLES'=>'семикратный',
#config
 'L_ACCES'=>'Тип (ы) аккаунта (ов) * авторизованные для доступа к плагину',
 'L_HELP_ACCES'=>'Какие профили * разрешено использовать плагин. Список разделен запятыми (по умолчанию PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Пользователям запрещен доступ к плагину (скрытое меню)',
 'L_HELP_DENY'=>'Которые являются идентификаторами пользователей, которым запрещено использовать плагин. Список через запятую (например, 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/ru.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Ключевые слова',
 'L_TITLE'=>'Изменить ключевые слова сайта',
 'L_DESCRIPTION'=>'Управление тегами сайта. Удалить или переименовать набор ключевых слов.',
 'L_FILTER_TAGS'=>'Ключевые слова фильтра',
 'L_FILTER_TAGS_PH'=>'Фильтр слова',
 'L_CANCEL'=>'Отменить все',
 'L_DEVIENT'=>'становится',
 'L_POUR'=>'для',
 'L_SEARCH'=>'Искать в статьях с этим ключевым словом',
 'L_RESTORE'=>'восстановление',
 'L_DEL'=>'вычеркивать',
 'L_RESTORE_ALL'=>'Восстановить все поля, оставленные пустыми',
 'L_DEL_ALL'=>'Очистить все поля',
 'L_ART_NUM'=>'Для товара (ов) с номером (ами)',
 'L_HELP_TAG_FIELD'=>'Если поле пустое, ключевое слово удаляется после сохранения',
 'L_HELP_TAG_CTRLZ'=>'Комбинация ключей Ctrl-z позволяет отменить',
 'L_TAGS_REFRESH'=>'обновление',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Файл Tags.xml обновляется по ключевым словам статей',
 'L_TAG_PLACEHOLDER'=>'Удалено, если оставить пустым',
 'L_DEDUPLICATED'=>'дедуплицированы',
 'L_IN_REALITY'=>'В реальности',
 'L_IS_UNIK'=>'Уникальный (это соло)',
 'L_DOUBLES'=>'двойной',
 'L_TRIPLES'=>'троек',
 'L_QUADRUPLES'=>'четверной',
 'L_QUINTUPLES'=>'пятикратный',
 'L_SEXTUPLES'=>'шестикратный',
 'L_SEPTUPLES'=>'семикратный',
 'L_OCTUPLES'=>'Октаплз',
 'L_NONUPLES'=>'Неуплы',
 'L_DECUPLES'=>'Десятикратно',
#config
 'L_ACCES'=>'Тип (ы) аккаунта (ов) * авторизованные для доступа к плагину',
 'L_HELP_ACCES'=>'Какие профили * разрешено использовать плагин. Список разделен запятыми (по умолчанию PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Пользователям запрещен доступ к плагину (скрытое меню)',
 'L_HELP_DENY'=>'Которые являются идентификаторами пользователей, которым запрещено использовать плагин. Список через запятую (например, 001,002,007).',
);
?>
